@@ -383,6 +383,36 @@ class ImportAdmin(IDAdmin):
                 if not os.path.exists(tempdir):
                     os.mkdir(tempdir)
 
+                # 找出在model定义的列
+                meta = self.model._meta
+                field_names = [field.name for field in meta.fields]
+                verbose_names = [field.verbose_name for field in meta.fields]
+
+                # --- 兼容导出时自定义的列名
+                if hasattr(self, 'extra_fields_dc') and getattr(self, 'extra_fields_dc'):
+                    _field_dc = dict(zip(field_names, verbose_names))
+                    _field_dc.update(self.extra_fields_dc)
+                    field_dc = {v: k for k,v in _field_dc.items()}
+                else:
+                    field_dc = dict(zip(verbose_names, field_names))
+
+                verbose_names = list(field_dc.keys())
+
+                dtype = None
+                for i in range(len(field_names)):
+                    field_name = field_names[i]
+                    field_type = get_field_type_in_py(self.model, field_name)
+                    verbose_name = verbose_names[i]
+                    if field_type == 'str':
+                        print(f'{field_name} --- {verbose_name} --- {field_type}')
+                        dc = {
+                            verbose_name: str,
+                        }
+                        if dtype is None:
+                            dtype = dc
+                        else:
+                            dtype.update(dc)
+
                 if f_format == 'csv':
                     try:
                         encoding = 'utf-8'
@@ -399,14 +429,14 @@ class ImportAdmin(IDAdmin):
                         f.write(file_data)
 
                     # 为解决字段内有逗号导致分割错误问题, 只能采用pd了
-                    df = pd.read_csv(fname, encoding=encoding)
+                    df = pd.read_csv(fname, encoding=encoding, dtype=dtype)
                 elif f_format == 'xls':
                     wb = xlrd.open_workbook(file_contents=read_data)
-                    df = pd.read_excel(wb)
+                    df = pd.read_excel(wb, dtype=dtype)
                 elif f_format == 'xlsx':
                     try:
                         wb = xlrd.open_workbook(file_contents=read_data)
-                        df = pd.read_excel(wb)
+                        df = pd.read_excel(wb, dtype=dtype)
                     except Exception as e:
                         raise TypeError(f'文件读入错误! 可转换为`xls`格式后重试. msg: {e}')
                 else:
@@ -417,21 +447,7 @@ class ImportAdmin(IDAdmin):
                 # 删除Unnamed列
                 df = df.loc[:, ~df.columns.str.match('Unnamed')]
 
-                # 找出在model定义的列
-                meta = self.model._meta
-                field_names = [field.name for field in meta.fields]
-                verbose_names = [field.verbose_name for field in meta.fields]
-
-                # --- 兼容导出时自定义的列名
-                if hasattr(self, 'extra_fields_dc') and getattr(self, 'extra_fields_dc'):
-                    _field_dc = dict(zip(field_names, verbose_names))
-                    _field_dc.update(self.extra_fields_dc)
-                    field_dc = {v: k for k,v in _field_dc.items()}
-                else:
-                    field_dc = dict(zip(verbose_names, field_names))
-
-                new_verbose_names = list(field_dc.keys())
-                valid_columns = [column_i in field_names or column_i in new_verbose_names for column_i in df.columns]
+                valid_columns = [column_i in field_names or column_i in verbose_names for column_i in df.columns]
                 df = df.loc[:, valid_columns]
                 titles = df.columns.tolist()
                 title_ls = [field_dc.get(title_i) if field_dc.get(title_i) else title_i for title_i in titles]
